/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global document, tizen, console, LANG_JSON_DATA, window*/

/**
 * To internationalize a Tizen Web application you must create locales/
 * directory in root of the application.
 * Inside it create a directory for each locale that has localized content.
 * The locale names are defined in the W3C IANA language subtag registry.
 *
 * In every locale directory create a language.js file with LANG_JSON_DATA
 * object defined in global stack. This object defines the key-value pairs
 * for localized strings.
 */

// strict wrapper
(function defineApp() {
    'use strict';

    /**
     * Hello world element.
     *
     * @memberof app
     * @private
     * @type {HTMLElement}
     */
    var helloWorldEl = document.getElementById('hello-world'),

        /**
         * Current language element.
         *
         * @memberof app
         * @private
         * @type {HTMLElement}
         */
        currentLanguageEl = document.getElementById('current-language');

    /**
     * Updates text for current language.
     *
     * @memberof app
     * @private
     */
    function updateLanguage() {
        helloWorldEl.innerText = LANG_JSON_DATA.helloWorld;
        currentLanguageEl.innerText = LANG_JSON_DATA.language;
    }

    // add eventListener for tizenhwkey
    document.addEventListener('tizenhwkey', function onHWKey(event) {
        if (event.keyName === 'back') {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (error) {
                console.error('Couldn\'t exit application');
            }
        }
    });

    window.addEventListener('load', updateLanguage);
})();
